@@ -30,6 +30,13 @@ else:
     BytesType = bytes
     INT_TYPES = int,
 
+try:
+    WindowsError
+except NameError:
+    class WindowsError(Exception):
+        "Windows error place-holder on platforms without support."
+        pass
+
 DBNAME = 'cache.db'
 ENOVAL = object()
 
@@ -276,6 +283,8 @@ class Disk(object):
 
         try:
             os.remove(full_path)
+        except WindowsError:
+            pass
         except OSError as error:
             if error.errno != errno.ENOENT:
                 # ENOENT may occur if two caches attempt to delete the same
